@@ -17,7 +17,6 @@
 
 #include "selectboardwindow.h"
 
-#include <KConfigGroup>
 #include <KLocalizedString>
 #include <QAbstractTableModel>
 #include <QDialogButtonBox>
@@ -155,7 +154,7 @@ void LevelTableModel::sort(int column, Qt::SortOrder order) {
     default: assert(0);
     }
 
-    qStableSort(m_levels.begin(), m_levels.end(), cmp);
+    std::stable_sort(m_levels.begin(), m_levels.end(), cmp);
     emit dataChanged(index(0, 0), index(rowCount() - 1, columnCount() -1));
 }
 
@@ -206,10 +205,10 @@ SelectBoardWindow::SelectBoardWindow(QWidget *parent)
         okButton->setEnabled(false);
     } else {
         resetSelection();
-        connect(ui->tableView->selectionModel(), SIGNAL(currentRowChanged(QModelIndex,QModelIndex)),
-                this, SLOT(selectedLevelChanged(QModelIndex,QModelIndex)));
-        connect(m_model.data(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                this, SLOT(levelDataChanged(QModelIndex,QModelIndex)));
+        connect(ui->tableView->selectionModel(), &QItemSelectionModel::currentRowChanged,
+                this, &SelectBoardWindow::selectedLevelChanged);
+        connect(m_model.data(), &QAbstractItemModel::dataChanged,
+                this, &SelectBoardWindow::levelDataChanged);
         updateDetails(m_levels[0]);
     }
 
